@@ -16,7 +16,12 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 import argparse
+import atexit
+import shutil
 import sys
+import tempfile
+
+from breezy.branch import Branch
 from breezy.workingtree import WorkingTree
 import locale
 locale.setlocale(locale.LC_ALL, '')
@@ -36,6 +41,8 @@ import breezy.bzr  # noqa: E402
 
 from breezy.trace import note  # noqa: E402
 
+import distro_info
+
 from . import (  # noqa: E402
     NotDebianPackage,
     PendingChanges,
@@ -49,8 +56,11 @@ from . import (  # noqa: E402
 def main(argv=None):
     parser = argparse.ArgumentParser(prog='lintian-brush')
     parser.add_argument(
-        '--no-update-changelog', action="store_true",
-        help="do not update the changelog")
+        '--no-update-changelog', action="store_false", default=None,
+        dest="update_changelog", help="do not update the changelog")
+    parser.add_argument(
+        '--update-changelog', action="store_true", dest="update_changelog",
+        help="force updating of the changelog", default=None)
     parser.add_argument(
         '--version', action='version', version='%(prog)s ' + version_string)
     parser.add_argument(
@@ -68,6 +78,16 @@ def main(argv=None):
         type=str, default='.')
     parser.add_argument(
         '--diff', help='Print resulting diff afterwards.', action='store_true')
+    parser.add_argument(
+        '--dry-run', help=(
+            'Do not make any changes to the current repository. '
+            'Note: currently creates a temporary clone of the repository.'),
+        action='store_true')
+    parser.add_argument(
+        '--modern', help=(
+            'Use features/compatibility levels that are not available in '
+            'stable. (makes backporting harder)'),
+        action='store_true', default=False)
     parser.add_argument(
         'fixers', metavar='FIXER', nargs='*',
         help='specific fixer to run')
@@ -89,7 +109,18 @@ def main(argv=None):
             note(tag)
     else:
         try:
-            wt = WorkingTree.open(args.directory)
+            if args.dry_run:
+                branch = Branch.open(args.directory)
+                td = tempfile.mkdtemp()
+                atexit.register(shutil.rmtree, td)
+                # TODO(jelmer): Make a slimmer copy
+                to_dir = branch.controldir.sprout(
+                    td, None, create_tree_if_local=True,
+                    source_branch=branch,
+                    stacked=branch._format.supports_stacking())
+                wt = to_dir.open_workingtree()
+            else:
+                wt = WorkingTree.open(args.directory)
         except NotBranchError:
             note('No version control directory found (e.g. a .git directory).')
             return 1
@@ -100,11 +131,17 @@ def main(argv=None):
         since_revid = wt.last_revision()
         if args.fixers:
             fixers = [f for f in fixers if f.name in args.fixers]
+        debian_info = distro_info.DebianDistroInfo()
+        if args.modern:
+            compat_release = debian_info.devel()
+        else:
+            compat_release = debian_info.stable()
         with wt.lock_write():
             try:
                 applied, failed = run_lintian_fixers(
                     wt, fixers,
-                    update_changelog=(not args.no_update_changelog),
+                    update_changelog=args.update_changelog,
+                    compat_release=compat_release,
                     verbose=args.verbose)
             except NotDebianPackage:
                 note("%s: Not a debian package.", wt.basedir)
